@@ -37,10 +37,10 @@ public:
     );
 
     void startOver();
-    SEXP nextComb();
-    SEXP nextNumCombs(SEXP RNum);
+    SEXP nextIter();
+    SEXP nextNumIters(SEXP RNum);
     SEXP nextGather();
-    SEXP currComb();
+    SEXP currIter();
     SEXP randomAccess(SEXP RindexVec);
     SEXP front();
     SEXP back();
